cwlVersion: v1.2

class: Workflow

label: SetArrayElementCoordinates
doc: |-
  Transform array element coordinates into the coordinate
  system required by the simulation pipeline (i.e., CORSIKA system).

inputs:

  - id: input_data
    type: File
    doc: |-
      Coordinates of array elements in UTMS system.
  - id: input_metadata
    type: File
    doc: |-
      Associated metadata.
  - id: schema_array_elements
    type: File
    doc: |-
      Schema file for definition of array elements data.
  - id: schema_parameter
    type: File
    doc: |-
      Schema file for definition of simulation model data.

outputs:

  - id: parameter_asserted
    type: File
    outputSource: receive_parameter_from_api/parameter_asserted

  - id: metadata_asserted
    type: File
    outputSource: receive_parameter_from_api/metadata_asserted

  - id: receive_data_db_success
    type: boolean
    outputSource: update_receive_data_to_data_base/db_success

  - id: validation_data_db_success
    type: boolean
    outputSource: update_validation_data_to_data_base/db_success

steps:

  - id: update_model_parameter_to_data_base
    run: ./update_data_base.cwl
    in:
      data: receive_parameter_from_api/parameter_asserted
      metadata: receive_parameter_from_api/metadata_asserted
    out:
      - db_success
    when: $(self.validation.validation_success)

  - id: update_validation_data_to_data_base
    run: ./update_data_base.cwl
    in:
      data: validation/validation_data
      metadata: validation/validatation_metadata
    out:
      - db_success
    when: $(self.validation.validation_success)

  - id: validation
    run: ./ValidateArrayElementCoordinates.cwl
    in:
      parameter: receive_parameter_from_api/parameter_asserted
      metadata: receive_parameter_from_api/metadata_asserted
      input_data: receive_data_from_api/input_data_asserted
      input_metadata: receive_data_from_api/input_metadata_asserted
    out:
      - validation_success
      - validation_data
      - validatation_metadata

  - id: update_receive_data_to_data_base
    run: ./update_data_base.cwl
    in:
      data: receive_data_from_api/input_data_asserted
      metadata: receive_data_from_api/input_metadata_asserted
    out:
      - db_success

  - id: receive_parameter_from_api
    run: ./receive_parameter_from_api.cwl
    in:
      parameter: derive_array_elements_coordinates/model_parameter
      metadata: derive_array_elements_coordinates/model_parameter_metadata
      parameter_schema: schema_parameter
    out:
      - parameter_asserted
      - metadata_asserted

  - id: derive_array_elements_coordinates
    run:
      ./derive_array_elements_coordinates.cwl
    in:
      data: receive_data_from_api/input_data_asserted
      metadata: receive_data_from_api/input_metadata_asserted
    out:
      - model_parameter
      - model_parameter_metadata

  - id: receive_data_from_api
    run: ./receive_data_from_api.cwl
    in:
      data: input_data
      metadata: input_metadata
      data_schema: schema_array_elements
    out:
      - input_data_asserted
      - input_metadata_asserted

requirements:
  SubworkflowFeatureRequirement: {}
